@@ -50,7 +50,8 @@ if __name__ == "__main__":
     cprint("Underline green color", "green", attrs=["underline"])
     cprint("Blink yellow color", "yellow", attrs=["blink"])
     cprint("Reversed blue color", "blue", attrs=["reverse"])
-    cprint("Concealed Magenta color", "magenta", attrs=["concealed"])
+    cprint("Concealed magenta color", "magenta", attrs=["concealed"])
+    cprint("Strike red color", "red", attrs=["strike"])
     cprint(
         "Bold underline reverse cyan color",
         "cyan",
